@@ -3,6 +3,8 @@
 # SPDX-License-Identifier: GPL-3.0-only
 """A stateful decoder of WWVB signals"""
 
+import sys
+from typing import Generator, List, Optional
 import wwvb
 
 # State 1: Unsync'd
@@ -20,9 +22,11 @@ import wwvb
 always_zero = set((4, 10, 11, 14, 20, 21, 34, 35, 44, 54))
 
 
-def wwvbreceive():  # pylint: disable=too-many-branches
+def wwvbreceive() -> Generator[
+    Optional[wwvb.WWVBTimecode], wwvb.AmplitudeModulation, None
+]:  # pylint: disable=too-many-branches
     """A stateful decoder of WWVB signals"""
-    minute = []
+    minute: List[wwvb.AmplitudeModulation] = []
     state = 1
 
     value = yield None
@@ -70,3 +74,22 @@ def wwvbreceive():  # pylint: disable=too-many-branches
                 value = yield tc
             else:
                 value = yield None
+
+
+def main() -> None:
+    """Read symbols on stdin and print any successfully-decoded minutes"""
+    decoder = wwvbreceive()
+    next(decoder)
+    decoder.send(wwvb.AmplitudeModulation.MARK)
+    for s in sys.argv[1:]:
+        for c in s:
+            decoded = decoder.send(wwvb.AmplitudeModulation(int(c)))
+            if decoded:
+                print(decoded)
+                w = wwvb.WWVBMinute.from_timecode_am(decoded)
+                if w:
+                    print(w)
+
+
+if __name__ == "__main__":  # pragma no cover
+    main()
