@@ -14,8 +14,9 @@ from . import iersdata
 ONE_DAY = datetime.timedelta(days=1)
 
 
-def end_of_month(d):
+def end_of_month(d: datetime.date) -> datetime.date:
     """Return the end of the month containing the day 'd'"""
+    d = d.replace(day=28)
     while True:
         d0 = d
         d = d + ONE_DAY
@@ -23,26 +24,17 @@ def end_of_month(d):
             return d0
 
 
-def next_month(d):
-    """Return the first day of hte next month after 'd'"""
-    while True:
-        d0 = d
-        d = d + ONE_DAY
-        if d.month != d0.month:
-            return d
-
-
 class TestLeapSecond(unittest.TestCase):
     """Leap second tests"""
 
-    def test_leap(self):
+    def test_leap(self) -> None:
         """Tests that the expected leap seconds all occur."""
         d = iersdata.DUT1_DATA_START
         e = datetime.date(2022, 1, 1)
         leap = []
         while d < e:
             eom = end_of_month(d)
-            nm = next_month(d)
+            nm = eom + ONE_DAY
             if wwvb.isls(d):
                 month_ends_dut1 = wwvb.get_dut1(eom)
                 month_starts_dut1 = wwvb.get_dut1(nm)
