@@ -12,7 +12,7 @@ import wwvb
 class TestPhaseModulation(unittest.TestCase):
     """Test Phase Modulation Signal"""
 
-    def test_pm(self):
+    def test_pm(self) -> None:
         """Compare the generated signal from a reference minute in NIST docs"""
         ref_am = (
             "2011000002"
@@ -35,8 +35,8 @@ class TestPhaseModulation(unittest.TestCase):
         ref_minute = wwvb.WWVBMinuteIERS(2012, 186, 17, 30, dst=3)
         ref_time = ref_minute.as_timecode()
 
-        test_am = ref_time.to_am_string("012")
-        test_pm = ref_time.to_pm_string("01")
+        test_am = ref_time.to_am_string(["0", "1", "2"])
+        test_pm = ref_time.to_pm_string(["0", "1"])
 
         self.assertEqual(ref_am, test_am)
         self.assertEqual(ref_pm, test_pm)
