@@ -64,7 +64,7 @@ def main() -> None:
         sz = min(event.width, event.height) - 8
         if sz < 0:
             return
-        canvas.coords(  # type: ignore
+        canvas.coords(
             circle,
             event.width // 2 - sz // 2,
             event.height // 2 - sz // 2,
